@@ -1,6 +1,6 @@
 /*
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2019 Derick Rethans                               |
+   | Copyright (c) 1997-2022 Derick Rethans                               |
    +----------------------------------------------------------------------+
    | This source file is subject to the 2-Clause BSD license which is     |
    | available through the LICENSE file, or online at                     |
@@ -113,7 +113,11 @@ static const op_usage opcodes[] = {
 	/*  42 */	{ "JMP", OP1_USED | OP1_OPLINE },
 	/*  43 */	{ "JMPZ", OP1_USED | OP2_USED | OP2_OPLINE },
 	/*  44 */	{ "JMPNZ", OP1_USED | OP2_USED | OP2_OPLINE },
+#if PHP_VERSION_ID < 80200
 	/*  45 */	{ "JMPZNZ", SPECIAL },
+#else
+	/*  45 */	{ "UNKNOWN [45]", ALL_USED },
+#endif
 	/*  46 */	{ "JMPZ_EX", ALL_USED | OP2_OPLINE },
 	/*  47 */	{ "JMPNZ_EX", ALL_USED | OP2_OPLINE },
 	/*  48 */	{ "CASE", ALL_USED },
@@ -342,6 +346,11 @@ static const op_usage opcodes[] = {
 	/*  197 */	{ "MATCH_ERROR", ALL_USED },
 	/*  198 */	{ "JMP_NULL", ALL_USED },
 	/*  199 */	{ "CHECK_UNDEF_ARGS", ALL_USED },
+#   if PHP_VERSION_ID >= 80100
+	/*  200 */	{ "FETCH_GLOBALS", ALL_USED },
+	/*  201 */	{ "VERIFY_NEVER_TYPE", ALL_USED },
+	/*  202 */	{ "ZEND_CALLABLE_CONVERT", ALL_USED },
+#   endif
 #  endif
 # else
 	/*  194 */	{ "FUNC_NUM_ARGS", ALL_USED },
@@ -586,12 +595,12 @@ static unsigned int vld_get_special_flags(const zend_op *op, unsigned int base_a
 				flags |= OP1_USED;
 			}
 			break;
-
+#if PHP_VERSION_ID < 80200
 		case ZEND_JMPZNZ:
 			flags = OP1_USED | OP2_USED | EXT_VAL_JMP_REL | OP2_OPNUM;
 //			op->result = op->op1;
 			break;
-
+#endif
 		case ZEND_FETCH_CLASS:
 			flags = EXT_VAL|RES_USED|OP2_USED;
 			break;
@@ -1015,13 +1024,13 @@ int vld_find_jumps(zend_op_array *opa, unsigned int position, size_t *jump_count
 		jumps[1] = VLD_ZNODE_JMP_LINE(opcode.op2, position, base_address);
 		*jump_count = 2;
 		return 1;
-
+#if PHP_VERSION_ID < 80200
 	} else if (opcode.opcode == ZEND_JMPZNZ) {
 		jumps[0] = VLD_ZNODE_JMP_LINE(opcode.op2, position, base_address);
 		jumps[1] = position + ((int32_t) opcode.extended_value / (int32_t) sizeof(zend_op));
 		*jump_count = 2;
 		return 1;
-
+#endif
 	} else if (opcode.opcode == ZEND_FE_FETCH_R || opcode.opcode == ZEND_FE_FETCH_RW) {
 		jumps[0] = position + 1;
 		jumps[1] = position + (opcode.extended_value / sizeof(zend_op));
