@@ -1,6 +1,6 @@
 /*
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2021 Derick Rethans                               |
+   | Copyright (c) 1997-2022 Derick Rethans                               |
    +----------------------------------------------------------------------+
    | This source file is subject to the 2-Clause BSD license which is     |
    | available through the LICENSE file, or online at                     |
@@ -17,6 +17,7 @@
 #include "php.h"
 #include "php_ini.h"
 #include "ext/standard/info.h"
+#include "ext/standard/php_string.h"
 #include "ext/standard/url.h"
 #include "php_vld.h"
 #include "srm_oparray.h"
@@ -25,12 +26,15 @@
 static zend_op_array* (*old_compile_file)(zend_file_handle* file_handle, int type);
 static zend_op_array* vld_compile_file(zend_file_handle*, int);
 
-#if PHP_VERSION_ID < 80000
-static zend_op_array* (*old_compile_string)(zval *source_string, char *filename);
-static zend_op_array* vld_compile_string(zval *source_string, char *filename);
-#else
+#if PHP_VERSION_ID >= 80200
+static zend_op_array* (*old_compile_string)(zend_string *source_string, const char *filename, zend_compile_position p);
+static zend_op_array* vld_compile_string(zend_string *source_string, const char *filename, zend_compile_position p);
+#elif PHP_VERSION_ID >= 80000
 static zend_op_array* (*old_compile_string)(zend_string *source_string, const char *filename);
 static zend_op_array* vld_compile_string(zend_string *source_string, const char *filename);
+#else
+static zend_op_array* (*old_compile_string)(zval *source_string, char *filename);
+static zend_op_array* vld_compile_string(zval *source_string, char *filename);
 #endif
 
 static void (*old_execute_ex)(zend_execute_data *execute_data);
@@ -56,7 +60,7 @@ zend_module_entry vld_module_entry = {
 	PHP_RINIT(vld),
 	PHP_RSHUTDOWN(vld),
 	PHP_MINFO(vld),
-	"0.17.2",
+	"0.18.0",
 	STANDARD_MODULE_PROPERTIES
 };
 
@@ -259,7 +263,13 @@ static int vld_dump_cle (zend_class_entry *class_entry)
 
 	if (ce->type != ZEND_INTERNAL_CLASS) {
 		if (VLD_G(path_dump_file)) {
-			fprintf(VLD_G(path_dump_file), "subgraph cluster_class_%s { label=\"class %s\";\n", ZSTRING_VALUE(ce->name), ZSTRING_VALUE(ce->name));
+#if PHP_VERSION_ID >= 70300
+			zend_string *tmp_zstr = php_addcslashes(ce->name, "\\", 1);
+			fprintf(VLD_G(path_dump_file), "subgraph \"cluster_class_%s\" { label=\"class %s\";\n", ZSTR_VAL(tmp_zstr), ZSTR_VAL(tmp_zstr));
+			zend_string_release(tmp_zstr);
+#else
+			fprintf(VLD_G(path_dump_file), "subgraph \"cluster_class_%s\" { label=\"class %s\";\n", ZSTRING_VALUE(ce->name), ZSTRING_VALUE(ce->name));
+#endif
 		}
 
 		zend_hash_apply_with_argument(&ce->function_table, (apply_func_arg_t) VLD_WRAP_PHP7(vld_check_fe), (void *)&have_fe);
@@ -287,9 +297,9 @@ static zend_op_array *vld_compile_file(zend_file_handle *file_handle, int type)
 {
 	zend_op_array *op_array;
 #if PHP_VERSION_ID < 80100
-	char *filename = file_handle->filename;
+	const char *filename = file_handle->filename;
 #else
-	char *filename = ZSTR_VAL(file_handle->filename);
+	const char *filename = ZSTR_VAL(file_handle->filename);
 #endif
 
 	if (!VLD_G(execute) &&
@@ -297,17 +307,22 @@ static zend_op_array *vld_compile_file(zend_file_handle *file_handle, int type)
 	     (VLD_G(skip_append)  && PG(auto_append_file)  && PG(auto_append_file)[0]  && PG(auto_append_file)  == filename)))
 	{
 		zend_op_array *ret;
-#if PHP_VERSION_ID < 80000
+#if PHP_VERSION_ID >= 80200
+		zend_string *nop = zend_string_init("RETURN ;", 8, 0);
+
+		ret = compile_string(nop, (const char*) "NOP", ZEND_COMPILE_POSITION_AFTER_OPEN_TAG);
+		zend_string_release(nop);
+#elif PHP_VERSION_ID >= 80000
+		zend_string *nop = zend_string_init("RETURN ;", 8, 0);
+
+		ret = compile_string(nop, (const char*) "NOP");
+		zend_string_release(nop);
+#else
 		zval nop;
 
 		ZVAL_STRINGL(&nop, "RETURN ;", 8);
 		ret = compile_string(&nop, (char*) "NOP");
 		zval_dtor(&nop);
-#else
-		zend_string *nop = zend_string_init("RETURN ;", 8, 0);
-
-		ret = compile_string(nop, (const char*) "NOP");
-		zend_string_release(nop);
 #endif
 		return ret;
 	}
@@ -334,15 +349,21 @@ static zend_op_array *vld_compile_file(zend_file_handle *file_handle, int type)
 
 /* {{{ zend_op_array vld_compile_string (source_string, filename)
  *    This function provides a hook for compilation */
-#if PHP_VERSION_ID < 80000
-static zend_op_array *vld_compile_string(zval *source_string, char *filename)
-#else
+#if PHP_VERSION_ID >= 80200
+static zend_op_array *vld_compile_string(zend_string *source_string, const char *filename, zend_compile_position p)
+#elif PHP_VERSION_ID >= 80000
 static zend_op_array *vld_compile_string(zend_string *source_string, const char *filename)
+#else
+static zend_op_array *vld_compile_string(zval *source_string, char *filename)
 #endif
 {
 	zend_op_array *op_array;
 
-	op_array = old_compile_string (source_string, filename);
+#if PHP_VERSION_ID >= 80200
+	op_array = old_compile_string(source_string, filename, p);
+#else
+	op_array = old_compile_string(source_string, filename);
+#endif
 
 	if (op_array) {
 		vld_dump_oparray (op_array);
